@@ -126,7 +126,7 @@ class HydraHead(HydraThread):
                         # Fetch rows from database queue and claim items before processing
                         if not hydra_queue: time.sleep(options.hydra_sleep); continue
                         claimed = hydra_queue.claim()
-                        stdlib.logw(claimed, "CLAIMED HYDRA QUEUE: %s" % hydra_queue['hydra_queue_id'])
+                        self.logw(claimed, "CLAIMED HYDRA QUEUE: %s" % hydra_queue['hydra_queue_id'])
                         if not claimed: continue
                         hydra_type = aegis.model.HydraType.get_id(hydra_queue['hydra_type_id'])
                         # Hydra Magic: Find the hydra_type specific function in a subclass of HydraHead
@@ -225,8 +225,9 @@ class Hydra(HydraThread):
                             if past_items and len(past_items):
                                 logging.error("HydraQueue has %s stuck items", len(past_items))
                                 for past_item in past_items:
-                                    logging.error("Unclaiming stuck hydra_queue_id: %s", past_item['hydra_queue_id'])
-                                    past_item.unclaim()
+                                    logging.error("Stuck hydra_queue_id: %s", past_item['hydra_queue_id'])
+                                    #logging.error("Unclaiming stuck hydra_queue_id: %s", past_item['hydra_queue_id'])
+                                    #past_item.unclaim()
 
                 except Exception as ex:
                     logging.exception("Batch had an inner loop failure.")
